Given a Neo4j based KG engine, provides summary information in the form of
node counts, category counts across nodes, relationship type counts, and
available properties.
The returned summary object prints a readable console report and also
contains
data frames with this information. Also returned are cats, preds, and
props entries, containing lists of available
categories/predicates/properties for convenient auto-completion in RStudio.
# S3 method for class 'neo4j_engine'
summary(object, ..., quiet = FALSE)A classed list of data frames and named lists.
if (FALSE) {
# prints a readable summary and returns a list of dataframes
stats <- monarch_engine() |> summary()
print(stats)
}